@@ -14,12 +14,17 @@ stemdotstats = function(ycol) {
 
 #' Plot a Cleveland dot plot.
 #'
-#' assumes that xvar is a factor variable
-#' sort < 0 sorts the factor levels in decreasing order (most frequent level first)
-#' sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
-#' sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
-#' stem = FALSE will plot only the dots, without the stem to the y=0 line.
-#' limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
+#' Plot counts of a categorical variable.
+#'
+#' Assumes that \code{xvar} is a factor or can be coerced to one (character or integral).
+#' \itemize{
+#' \item sort < 0 sorts the factor levels in decreasing order (most frequent level first)
+#' \item sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
+#' \item sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
+#' \item stem = FALSE will plot only the dots, without the stem to the y=0 line.
+#' \item limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
+#' }
+#'
 #' @param frm data frame to get values from
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
@@ -46,10 +51,17 @@ stemdotstats = function(ycol) {
 #' WVPlots::ClevelandDotPlot(randomDraws, "letter",
 #'   title = "Example Cleveland-style dot plot")
 #'
+#' # Note the use of sort = 0, and that the graph correctly includes counts
+#' # with no occurrences (5, and 7)
+#' WVPlots::ClevelandDotPlot(mtcars, "carb", sort = 0, "Example of counting integer values")
 #' @export
 ClevelandDotPlot = function(frm, xvar, title, ...,
                             sort=-1, limit_n = NULL, stem=TRUE) {
-  checkArgs(frame=frm,xvar=xvar,yvar=xvar,title=title,...)
+  frm <- check_frame_args_list(...,
+                               frame = frm,
+                               name_var_list = list(xvar = xvar),
+                               title = title,
+                               funname = "WVPlots::ClevelandDotPlot")
   if(!(is.null(limit_n) || isScalar(limit_n))) {
     stop("parameter limit_n must either be null or a numeric scalar")
   }
