@@ -1,6 +1,8 @@
 
 #' Plot the distribution of a variable with a tail shaded
 #'
+#' Plot the distribution of a variable with a tail shaded.
+#'
 #' @param frame data frame to get values from
 #' @param xvar name of the variable to be density plotted
 #' @param threshold boundary value for the tail
@@ -18,8 +20,14 @@
 #'                        title="Example shaded density plot, right tail")
 #'
 #' @export
-ShadedDensity <- function(frame, xvar, threshold,title,..., tail="left") {
-  checkArgs(frame=frame,xvar=xvar,yvar=xvar,title=title,...)
+ShadedDensity <- function(frame, xvar, threshold, title,
+                          ...,
+                          tail="left") {
+  frame <- check_frame_args_list(...,
+                                 frame = frame,
+                                 name_var_list = list(xvar = xvar),
+                                 title = title,
+                                 funname = "WVPlots::ShadedDensity")
   x <- NULL # used as a symbol, declare not an unbound variable
 
   # calculate the distribution by hand
